==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/CspmMonitorAwsOfferingNativeCloudConnectionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.CspmMonitorAwsOfferingNativeCloudConnectionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The native cloud connection configuration
 * @property cloudRoleArn The cloud role ARN in AWS for this feature
 */
public data class CspmMonitorAwsOfferingNativeCloudConnectionArgs(
    public val cloudRoleArn: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.CspmMonitorAwsOfferingNativeCloudConnectionArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.CspmMonitorAwsOfferingNativeCloudConnectionArgs =
        com.pulumi.azurenative.security.inputs.CspmMonitorAwsOfferingNativeCloudConnectionArgs.builder()
            .cloudRoleArn(cloudRoleArn?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CspmMonitorAwsOfferingNativeCloudConnectionArgs].
 */
@PulumiTagMarker
public class CspmMonitorAwsOfferingNativeCloudConnectionArgsBuilder internal constructor() {
    private var cloudRoleArn: Output<String>? = null

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("vwrsnyxbkjwokvvj")
    public suspend fun cloudRoleArn(`value`: Output<String>) {
        this.cloudRoleArn = value
    }

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("rfunxrwmxhrllfuk")
    public suspend fun cloudRoleArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cloudRoleArn = mapped
    }

    internal fun build(): CspmMonitorAwsOfferingNativeCloudConnectionArgs =
        CspmMonitorAwsOfferingNativeCloudConnectionArgs(
            cloudRoleArn = cloudRoleArn,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/inputs/CspmMonitorAwsOfferingNativeCloudConnectionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.inputs

import com.pulumi.azurenative.security.inputs.CspmMonitorAwsOfferingNativeCloudConnectionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The native cloud connection configuration
 * @property cloudRoleArn The cloud role ARN in AWS for this feature
 */
public data class CspmMonitorAwsOfferingNativeCloudConnectionArgs(
    public val cloudRoleArn: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.security.inputs.CspmMonitorAwsOfferingNativeCloudConnectionArgs> {
    override fun toJava():
        com.pulumi.azurenative.security.inputs.CspmMonitorAwsOfferingNativeCloudConnectionArgs =
        com.pulumi.azurenative.security.inputs.CspmMonitorAwsOfferingNativeCloudConnectionArgs.builder()
            .cloudRoleArn(cloudRoleArn?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [CspmMonitorAwsOfferingNativeCloudConnectionArgs].
 */
@PulumiTagMarker
public class CspmMonitorAwsOfferingNativeCloudConnectionArgsBuilder internal constructor() {
    private var cloudRoleArn: Output<String>? = null

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("aeubmxxxgwxfxslp")
    public suspend fun cloudRoleArn(`value`: Output<String>) {
        this.cloudRoleArn = value
    }

    /**
     * @param value The cloud role ARN in AWS for this feature
     */
    @JvmName("bsvuluxcotcgygmm")
    public suspend fun cloudRoleArn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cloudRoleArn = mapped
    }

    internal fun build(): CspmMonitorAwsOfferingNativeCloudConnectionArgs =
        CspmMonitorAwsOfferingNativeCloudConnectionArgs(
            cloudRoleArn = cloudRoleArn,
        )
}
